/*
*  Plugin to show drag operation state under cursor
*
*  Distributed under the terms of the GNU Library General Public License
*
*  @package ddi (Drag'n'Drop Interface)
*  @version 1.3
*  @title Show drag operation state plugin
*  @author Ilya Lebedev (ilya@lebedev.net), (c) 2005
*
*  Revision history
*
*  v1.3
*  - dragstart.after callback
*  + plugin group DDI_VISUAL
*  + shutdown method
*
*  v1.2.1
*  % z-index to prevent tip to be overlapped
*
*  v1.2
*  % some performance issues (like innerHTML usage)
*  + dragstart.after callback to change tooltip's display mode only once
*  - removed some junk
*  + public properties - tooltip coordinates, relative to mouse pointer
*
*  v1.1
*  + first public release
*/
__DDI__.plugin.dragStateAsCursor = new function () {
  var self = this;
  this.name = 'Show drag state';
  this.description = 'Plugin is used to show drag state near mouse pointer';
  this.group = 'DDI_VISUAL';
  var el = null;
  var ________________________Publics______________________;
  this.opacity = 50;
  /*
  *  Tooltip X coordinate, relative to cursor
  *
  *  @type integer
  *  @access public
  */
  this.t_x = 10;
  /*
  *  Tooltip X coordinate, relative to cursor
  *
  *  @type integer
  *  @access public
  */
  this.t_y = 2;
  /*
  *  Private methods.
  *  Do not call them directly
  */
  this.init = function () {
    el = document.createElementExt("DIV", null, null,
                                   [['position','absolute'],
                                    ['border', '1px solid black'],
                                    ['display', 'none'],
                                    ['zIndex', '9999']
                                   ],
                                   [document.createTextNode('')]
                                  );
    var body = document.getElementsByTagName('body')[0];
    body.appendChild(el);
  }
  this.drag = {
    'after' : function (e) {
      switch (e.__dataTransfer.getDragState()) {
        case 1 : 
          el.firstChild.nodeValue = 'copy-allowed';
          break;
        case 2 : 
          el.firstChild.nodeValue = 'move-allowed';
          break;
        case 4 : 
          el.firstChild.nodeValue = 'link-allowed';
          break;
        case 0 : 
        default:
          el.firstChild.nodeValue = 'no-drop';
      }
      el.style.top = e.__pageY+self.t_y+'px';
      el.style.left = e.__pageX+self.t_x+'px';
      el.style.display = 'block';
    }
  }
  this.dragend = {
    'after' : function (e) {
      if (el) el.style.display = 'none';
    }
  }
  this.shutdown = function() {
    if (el != null) {
      el.removeNode(true);
      el = null;
    }
  }
};
