/*
*  Plugin shows what do we dragging
* 
*  Distributed under the terms of the GNU Library General Public License
*
*  @package ddi (Drag'n'Drop Interface)
*  @version 1.1
*  @title Dragged element tooltip
*  @author Ilya Lebedev (ilya@lebedev.net), (c) 2005
*
*  Revision history
*  v1.1
*  + compatibility to IE, which does not draw table parts within simple DIV containers
*  % bug with showing tip before drag actually starts
*  % z-index to prevent tip to be overlapped
*  + plugin group DDI_VISUAL
*  % deletion of the tooltip
*
*  v1.0
*  + first public release
*/
__DDI__.plugin.draggedElementTip = new function () {
  var self = this;
  var el = null;
  this.name = 'Dragged element tooltip';
  this.description = 'Plugin shows transparent copy of dragged element near mouse pointer';
  this.group = 'DDI_VISUAL';
  var ________________________Publics______________________;
  /*
  *  Opacity percentage
  *
  *  @type integer
  *  @access public
  */
  this.opacity = 75;
  /*
  *  Tooltip X coordinate, relative to cursor
  *
  *  @type integer
  *  @access public
  */
  this.t_x = 10;
  /*
  *  Tooltip X coordinate, relative to cursor
  *
  *  @type integer
  *  @access public
  */
  this.t_y = 18;
  /*
  *  Tooltip width
  *
  *  @type integer
  *  @access public
  */
  this.t_w = 250;
  /*
  *  Tooltip height
  *
  *  @type integer
  *  @access public
  */
  this.t_h = 75;
  /*
  *  Private methods.
  *  Do not call them directly
  */
  this.dragstart = {
    'after' : function (e) {
      var el1, el2;
      var tel = e.__dataTransfer.getClonedElement();
      switch (tel.tagName.toLowerCase()) {
        case "th":
        case "td":
          el1 = 'div';
          el2 = 'table';
          tel = document.createElementExt('tbody',null,null,null,[document.createElementExt('tr',null,null,null,[tel])]);
          break;
        case "tr":
          tel = document.createElementExt('tbody',null,null,null,[tel]);
        case "thead":
        case "tbody":
        case "tfoot":
          el1 = 'div';
          el2 = 'table';
          break;
        default:
          el1 = el2 = 'div';
      }
      el = document.createElementExt(el1,null,null,[['-moz-opacity',self.opacity/100],
                                                    ['opacity',self.opacity/100],
                                                    ['-khtml-opacity',self.opacity/100],
                                                    ['filter','Alpha(Opacity='+self.opacity+')'],
                                                    ['position','absolute'],
                                                    ['width',self.t_w+'px'],
                                                    ['height',self.t_h+'px'],
                                                    ['overflow','hidden'],
                                                    ['zIndex',9999],
                                                    ['display','none']],
                                                    [document.createElementExt(el2,null,null,[['position','relative']],
                                                                               [tel])]);
      el.firstChild.firstChild.style.margin = 0;
      el.firstChild.firstChild.style.padding = 0;
      el.firstChild.firstChild.style.top = 0;
      el.firstChild.firstChild.style.left = 0;
      var body = document.getElementsByTagName('body')[0];
      body.appendChild(el);
    }
  }
  this.drag = {
    'before' : function (e) {
      if (el) {
        el.style.left = e.__pageX+self.t_x+'px';
        el.style.top = e.__pageY+self.t_y+'px';
        el.style.display = 'block'
      }
      return true;
    }
  }
  this.dragend = {
    'after' : function (e) {
      if (el != null) {
        el.style.display = 'none';
        el.removeNode(true);
        el = null;
      }
    }
  }
}
